@@ -1,7 +1,7 @@
 import unittest
 
 loader = unittest.TestLoader()
-suite = loader.discover('test', pattern='test_*.py')
+suite = loader.discover('tests', pattern='test_*.py')
 
 runner = unittest.TextTestRunner()
 runner.run(suite)
